==> haskell-wl-pprint-extras-3.5.0.5-81-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-extras
version: 3.5.0.5
id: wl-pprint-extras-3.5.0.5-LH4BswsZMhsChKV6fGC237
key: wl-pprint-extras-3.5.0.5-LH4BswsZMhsChKV6fGC237
license: BSD-3-Clause
copyright: Copyright (C) 2011-2012 Edward A. Kmett,
           Copyright (C) 2000 Daan Leijen
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-extras/
synopsis: A free monad based on the Wadler/Leijen pretty printer
description:
    A free monad based on the Wadler/Leijen pretty printer
category: Control, Monads, Text
abi: bb8155289fd41bc5c12bb57b38c0df6d
exposed: True
exposed-modules:
    Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-extras-3.5.0.5
library-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/wl-pprint-extras-3.5.0.5
hs-libraries: HSwl-pprint-extras-3.5.0.5-LH4BswsZMhsChKV6fGC237
depends:
    base-4.12.0.0 containers-0.6.0.1
    semigroupoids-5.3.2-GR99r82ABXrEII06k6CNVk text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-extras-3.5.0.5-82-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-extras
version: 3.5.0.5
id: wl-pprint-extras-3.5.0.5-CV1NIPz6G3e7Ee20Nte5B2
key: wl-pprint-extras-3.5.0.5-CV1NIPz6G3e7Ee20Nte5B2
license: BSD-3-Clause
copyright: Copyright (C) 2011-2012 Edward A. Kmett,
           Copyright (C) 2000 Daan Leijen
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-extras/
synopsis: A free monad based on the Wadler/Leijen pretty printer
description:
    A free monad based on the Wadler/Leijen pretty printer
category: Control, Monads, Text
abi: a2f8f2cad6a9f03ff84e0acdaae38f63
exposed: True
exposed-modules:
    Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-extras-3.5.0.5
library-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/wl-pprint-extras-3.5.0.5
hs-libraries: HSwl-pprint-extras-3.5.0.5-CV1NIPz6G3e7Ee20Nte5B2
depends:
    base-4.12.0.0 containers-0.6.0.1
    semigroupoids-5.3.2-2VNO4X3Idi16ncxsqdERqd text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
